@@ -9,7 +9,7 @@
 #
 package Config::Model::Tk::LeafEditor ;
 BEGIN {
-  $Config::Model::Tk::LeafEditor::VERSION = '1.319';
+  $Config::Model::Tk::LeafEditor::VERSION = '1.320';
 }
 
 use strict;
@@ -121,7 +121,7 @@ sub Populate {
     }
 
     $cw->ConfigModelNoteEditor( -object => $leaf )->pack;
-    $cw->add_warning($leaf)->pack(@fx) ;
+    $cw->add_warning($leaf, 'edit')->pack(@fx) ;
     $cw->add_info_button()->pack( @fx,qw/-anchor n/) ;
     $cw->add_summary($leaf)->pack(@fx) ;
     $cw->add_description($leaf)->pack(@fx) ;
